#
# spec file for package python-sklearn-pandas
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         skip_python2 1
# SciPy 1.6.0 dropped support for Python 3.6
%define         skip_python36 1
Name:           python-sklearn-pandas
Version:        2.2.0
Release:        2.8
Summary:        Pandas integration with sklearn
License:        BSD-2-Clause AND Zlib
Group:          Development/Languages/Python
URL:            https://github.com/scikit-learn-contrib/sklearn-pandas
Source:         %{url}/archive/v%{version}.tar.gz#/sklearn-pandas-%{version}-gh.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.18.1
Requires:       python-pandas >= 1.0.5
Requires:       python-scikit-learn >= 0.23.0
Requires:       python-scipy >= 1.4.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module numpy >= 1.18.1}
BuildRequires:  %{python_module pandas >= 1.0.5}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scikit-learn >= 0.23.0}
BuildRequires:  %{python_module scipy >= 1.4.1}
# /SECTION
%python_subpackages

%description
This module provides a bridge between Scikit-Learn's machine learning
methods and pandas-style Data Frames.

%prep
%setup -q -n sklearn-pandas-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Some tests are broken with the latest version of scikit-learn
# gh#scikit-learn-contrib/sklearn-pandas#248
donttest="test_onehot_df or test_dict_vectorizer"
%pytest -k "not (README.rst or $donttest)"

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/sklearn_pandas*

%changelog
* Mon Feb  6 2023 Daniel Garcia <daniel.garcia@suse.com>
- Disable broken tests gh#scikit-learn-contrib/sklearn-pandas#248
* Sat Feb 12 2022 Arun Persaud <arun@gmx.de>
- update to version 2.2.0:
  * Added an ability to provide callable functions instead of static
    column list.
- changes from version 2.1.0:
  * Removed test for Python 3.6 and added Python 3.9
  * Added deprecation warning for NumericalTransformer
  * Fixed pickling issue causing integration issues with Baikal.
  * Started publishing package to conda repo
* Thu Jan 28 2021 Ben Greiner <code@bnavigator.de>
- update to version 2.0.4
  * Explicitly handling serialization (#224)
  * document fixes
  * Making transform function thread safe (#194)
  * Switched to nox for unit testing (#226)
- Changlog for 2.0.3
  * Added elapsed time information for each feature.
- Skip python36 build because of SciPy 1.6.0
- Get the GitHub archive for the tests and run them
- No extra mock required
* Sat Oct 10 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * updated versions of required packages
- update to version 2.0.2:
  * Fix DataFrameMapper drop_cols attribute naming consistency with
    scikit-learn and initialization.
- changes from version 2.0.1:
  * Added an option to explicitly drop columns.
- changes from version 2.0.0:
  * Deprecated support for Python < 3.6.
  * Deprecated support for old versions of scikit-learn, pandas and
    numpy. Please check setup.py for minimum requirement.
  * Removed CategoricalImputer, cross_val_score and GridSearchCV. All
    these functionality now exists as part of scikit-learn. Please use
    SimpleImputer instead of CategoricalImputer. Also Cross validation
    from sklearn now supports dataframe so we don't need to use cross
    validation wrapper provided over here.
  * Added NumericalTransformer for common numerical
    transformations. Currently it implements log and log1p
    transformation.
  * Added prefix and suffix options. See examples above. These are
    usually helpful when using gen_features.
  * Added drop_cols argument to DataframeMapper. This can be used to
    explicitly drop columns
* Mon Jan  6 2020 Todd R <toddrme2178@gmail.com>
- Drop python2 subpackage due to dependencies dropping python2.
* Sat Dec  8 2018 Arun Persaud <arun@gmx.de>
- update to version 1.8.0:
  * Add FunctionTransformer class (#117).
  * Fix column names derivation for dataframes with multi-index or
    non-string columns (#166).
  * Change behaviour of DataFrameMapper's fit_transform method to
    invoke each underlying transformers' native fit_transform if
    implemented. (#150)
* Sun Sep  2 2018 arun@gmx.de
- specfile:
  * remove devel from noarch
  * be more specific in %%files section
- update to version 1.7.0:
  * Fix issues with unicode names in get_names (#160).
  * Update to build using numpy==1.14 and python==3.6 (#154).
  * Add strategy and fill_value parameters to CategoricalImputer to
    allow imputing with values other than the mode (#144), (#161).
  * Preserve input data types when no transform is supplied (#138).
* Thu May 24 2018 toddrme2178@gmail.com
- spec file cleanups
* Thu Nov  9 2017 arun@gmx.de
- update to version 1.6.0:
  * Add column name to exception during fit/transform (#110).
  * Add gen_feature helper function to help generating the same
    transformation for multiple columns (#126).
* Fri Oct 20 2017 toddrme2178@gmail.com
- initial version
